@@ -5,6 +5,7 @@ Created on 20 oct. 2012
 '''
 
 from distutils.command.build import build as ori_build
+from obidistutils.serenity.checksystem import is_mac_system
 
 
 class build(ori_build):
@@ -24,7 +25,11 @@ class build(ori_build):
     def has_littlebigman(self):
         return True
     
+    def has_pidname(self):
+        return is_mac_system()
+    
     sub_commands = [('littlebigman', has_littlebigman),
+                    ('pidname',has_pidname),
                     ('build_ctools', has_ctools),
                     ('build_files', has_files),
                     ('build_cexe', has_executables),
